// Copyright (C) 2008 - 2010 - Michael Baudin

function flps = flps_IEEEdoubleext ( )
  //   Returns an IEEE double extended floating point system.
  //
  // Calling Sequence
  //   flps = flps_IEEEdoubleext ( )
  //
  // Parameters
  //   flps: a new floating point system
  //
  // Description
  //   Returns the floating point system for a IEEE double extended.
  //   This format is not standard : the choice provided by this 
  //   function is just an example of double extended floating point 
  //   format.
  //   Caution: Scilab uses IEEE doubles to store values.
  //   As a consequence, the fields vmin, vmax and alpha are set to nan
  //   for this system.
  //
  // Examples
  // flps = flps_IEEEdoubleext ( )
  //
  // Authors
  // Michael Baudin, 2008 - 2010
  //
  // Bibliography
  //   "Handbook of floating-point arithmetic", Jean-Michel Muller, Nicolas Brisebarre, Florent de Dinechin, Claude-Pierre Jeannerod, Vincent Lefevre, Guillaume Melquiond, Nathalie Revol, Damien Stehle, Serge Torres, Birkhauser Boston, 2010

  flps = flps_systemnew ( );
  flps.radix = 2
  flps.p = 64
  flps.emin = -16381
  flps.emax = 16384
  flps.vmin = %nan
  flps.vmax = %nan
  flps.eps = 1.08420217248550440e-019
  flps.r = 1
  flps.gu = %t
  flps.alpha = %nan
endfunction

