// Copyright (C) 2008 - 2010 - Michael Baudin

function flps = flps_format2system ( r , p , e )
  //   Returns the floating point system of the given format.
  //
  // Calling Sequence
  //   flps = flps_format2system ( r , p , e )
  //
  // Parameters
  //   r: the radix
  //   p: the precision, i.e. the number of digits in the significant
  //   e: the number of digits in the exponent
  //
  // Description
  //   This function is so that, r=2, p=53, e=11 should
  //   reasonably match the particular settings of IEEE doubles.
  //
  // Examples
  // flps = flps_format2system ( 2 , 53 , 11 )
  //
  // Authors
  // Michael Baudin, 2008 - 2010
  //
  // Bibliography
  //   "Handbook of floating-point arithmetic", Jean-Michel Muller, Nicolas Brisebarre, Florent de Dinechin, Claude-Pierre Jeannerod, Vincent Lefevre, Guillaume Melquiond, Nathalie Revol, Damien Stehle, Serge Torres, Birkhauser Boston, 2010


  flps = flps_systemnew ( )
  flps.radix = r
  flps.p = p
  flps.emin = -r^(e-1) + 2
  flps.emax = r^(e-1)-1
  flps.vmin = r^(flps.emin)
  flps.vmax = r^(flps.emax)
  flps.eps = r^(1-p)
  flps.r = 1
  flps.gu = %t
endfunction

