// Copyright (C) 2008 - 2010 - Michael Baudin

function isieee = flps_isIEEE ( )
  //   Returns true if the current system satisfies basic IEEE requirements.
  //
  // Calling Sequence
  //   isieee = flps_isIEEE ( )
  //
  // Parameters
  //   isieee: %t if the current system satisfies basic IEEE requirements 
  //
  // Description
  //   This function uses flps_radix and flps_emin to check that 
  //   current rounding mode is based on round-to-nearest and that
  //   graceful underflow is supported.
  //   In practice, this function should never return false.
  //   Caution : not all aspects of the IEEE standard are 
  //   checked by this function. For example, the IEEE standard
  //   requires particular features of the elementary operators, 
  //   the management of nans, infs, etc... None of these 
  //   properties are checked.
  //
  // Examples
  // // The following should return %t
  // isieee = flps_isIEEE ( )
  //
  // Authors
  //   Michael Baudin, 2008 - 2010
  //
  // Bibliography
  //   "Handbook of floating-point arithmetic", Jean-Michel Muller, Nicolas Brisebarre, Florent de Dinechin, Claude-Pierre Jeannerod, Vincent Lefevre, Guillaume Melquiond, Nathalie Revol, Damien Stehle, Serge Torres, Birkhauser Boston, 2010

  f1 = flps_systemnew("current")
  f2 = flps_IEEEdouble ( )
  isieee = and( f1 == f2 )
endfunction

