// Copyright (C) 2008 - 2010 - Michael Baudin
// <-- JVM NOT MANDATORY -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//---
b = 2;
x = 1;
[ f , e ] = flps_frexp ( b , x );
y = f * b^e;
assert_equal ( x , y );
assert_equal ( f , 0.5 );
assert_equal ( e , 1 );
//---
b = 3;
x = 1;
[ f , e ] = flps_frexp ( b , x , "v1" );
y = f * b^e;
assert_equal ( x , y );
assert_close ( f , 1/3 , %eps );
assert_equal ( e , 1 );
//---
b = 3;
x = 2;
[ f , e ] = flps_frexp ( b , x , "v1" );
y = f * b^e;
assert_equal ( x , y );
assert_close ( f , 2/3 , %eps );
assert_equal ( e , 1 );
//---
b = 2;
x = 1;
[ f , e ] = flps_frexp ( b , x , "v2" );
y = f * b^e;
assert_equal ( x , y );
assert_equal ( f , 1 );
assert_equal ( e , 0 );
//---
b = 2;
x = 1/3;
[ f , e ] = flps_frexp ( b , x , "v2" );
y = f * b^e;
assert_equal ( x , y );
assert_close ( f , 4/3 , %eps );
assert_equal ( e , -2 );
//---
b = 2;
x = -8;
[ f , e ] = flps_frexp ( b , x , "v2" );
y = f * b^e;
assert_equal ( x , y );
assert_equal ( f , -1 );
assert_equal ( e , 3 );
//---
b = 3;
x = 1;
[ f , e ] = flps_frexp ( b , x , "v2" );
y = f * b^e;
assert_equal ( x , y );
assert_equal ( f , 1 );
assert_equal ( e , 0 );
//---
b = 3;
x = 2;
[ f , e ] = flps_frexp ( b , x , "v2" );
y = f * b^e;
assert_equal ( x , y );
assert_equal ( f , 2 );
assert_equal ( e , 0 );
//---
b = [3 3 3 3];
x = [1 2 3 4];
[ f , e ] = flps_frexp ( b , x , "v1" );
y = f .* b.^e;
assert_equal ( x , y );
assert_close ( f , [1/3    2/3    1/3    4/9] , %eps );
assert_equal ( e , [1.    1.    2.    2] );
//---
b = [3 3 3 3];
x = [1 2 3 4];
[ f , e ] = flps_frexp ( b , x , "v2" );
y = f .* b.^e;
assert_equal ( x , y );
assert_close ( f , [1.    2.    1.    4/3] , %eps );
assert_equal ( e , [0.    0.    1.    1] );

