// Copyright (C) 2008 - 2010 - Michael Baudin
// <-- JVM NOT MANDATORY -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//--
flps = flps_IEEEsingle ( );
flpn = flps_numberformat ( flps , 1/3 );
assert_equal ( flpn.M , 11184811 );
assert_equal ( flpn.e , -2 );
assert_equal ( flpn.m , 1.3333333730697631835938 );
assert_equal ( flpn.s , 0 );
flpn
//--
flps = flps_IEEEsingle ( );
flpn = flps_numberformat ( flps , 3*2^-128 );
assert_equal ( flpn.M , 6291456 );
assert_equal ( flpn.e , -126 );
assert_equal ( flpn.m , 0.75 );
assert_equal ( flpn.s , 0 );
flpn

/////////////////////////////////////////////////////////////
// Check rounding modes : default mode is round to nearest
flps = flps_format2system ( 2 , 3 , 3 );

flpn = flps_numberformat ( flps , 0.54 );
assert_equal ( flpn.M , 4 );
//
flpn = flps_numberformat ( flps , 0.60 );
assert_equal ( flpn.M , 5 );
//
flpn = flps_numberformat ( flps , -0.54 );
assert_equal ( flpn.M , -4 );
//
flpn = flps_numberformat ( flps , -0.60 );
assert_equal ( flpn.M , -5 );

// A case of tie: check that round to even is applied
x= 4.5 * 2^(-1-3+1);
flpn = flps_numberformat ( flps , x );
assert_equal ( flpn.M , 4 );

// A case of tie: check that round to even is applied
x= 4.5 * 2^(0-3+1);
flpn = flps_numberformat ( flps , x );
assert_equal ( flpn.M , 4 );

// A case of tie: check that round to even is applied
x= -4.5 * 2^(0-3+1);
flpn = flps_numberformat ( flps , x );
assert_equal ( flpn.M , -4 );

// A case where the number is rounded up, which makes the exponent increase
// to keep the number normalized
flpn = flps_numberformat ( flps , 0.49 );
assert_equal ( flpn.M , 4 );
assert_equal ( flpn.e , -1 );

/////////////////////////////////////////////////////////////

// Check rounding modes : set rounding mode to round up
flps = flps_format2system ( 2 , 3 , 3 );
flps.r = 2;

flpn = flps_numberformat ( flps , 0.54 );
assert_equal ( flpn.M , 5 );
//
flpn = flps_numberformat ( flps , 0.60 );
assert_equal ( flpn.M , 5 );
//
flpn = flps_numberformat ( flps , -0.54 );
assert_equal ( flpn.M , -4 );
//
flpn = flps_numberformat ( flps , -0.60 );
assert_equal ( flpn.M , -4 );

// A case where the number is rounded up, which makes the exponent increase
// to keep the number normalized
flpn = flps_numberformat ( flps , 0.99 );
assert_equal ( flpn.M , 4 );
assert_equal ( flpn.e , 0 );

/////////////////////////////////////////////////////////////

// Check rounding modes : set rounding mode to round down
flps = flps_format2system ( 2 , 3 , 3 );
flps.r = 3;

flpn = flps_numberformat ( flps , 0.54 );
assert_equal ( flpn.M , 4 );
//
flpn = flps_numberformat ( flps , 0.60 );
assert_equal ( flpn.M , 4 );
//
flpn = flps_numberformat ( flps , -0.54 );
assert_equal ( flpn.M , -5 );
//
flpn = flps_numberformat ( flps , -0.60 );
assert_equal ( flpn.M , -5 );

// A case where the number is rounded up, which makes the exponent decrease
// to keep the number normalized
flpn = flps_numberformat ( flps , -0.49 );
assert_equal ( flpn.M , -4 );
assert_equal ( flpn.e , -1 );

/////////////////////////////////////////////////////////////

// Check rounding modes : set rounding mode to round to zero
flps = flps_format2system ( 2 , 3 , 3 );
flps.r = 4;

flpn = flps_numberformat ( flps , 0.54 );
assert_equal ( flpn.M , 4 );
//
flpn = flps_numberformat ( flps , 0.60 );
assert_equal ( flpn.M , 4 );
//
flpn = flps_numberformat ( flps , -0.54 );
assert_equal ( flpn.M , -4 );
//
flpn = flps_numberformat ( flps , -0.60 );
assert_equal ( flpn.M , -4 );

