// Copyright (C) 2010 - Michael Baudin

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

d = flps_tobary ( 1 , 2 , 2 );
assert_equal ( d , [1 0]' );

x = 1/3+1/3^3;
d = flps_tobary ( x , 3 , 4 );
assert_equal ( d , [0 1 0 1]' );

x = 1 + 1/2 + 1/2^3 + 1/2^5;
d = flps_tobary ( x , 2 , 6 );
assert_equal ( d , [1 1 0 1 0 1]' );


